Index: src/core/SkScaleToSides.h |
diff --git a/src/core/SkScaleToSides.h b/src/core/SkScaleToSides.h |
index c3fa172f672588d27c29e95436c0bc0320d05f3c..49201d0361b45d35aae4ac3f6dc68f66f49dc167 100644 |
--- a/src/core/SkScaleToSides.h |
+++ b/src/core/SkScaleToSides.h |
@@ -12,7 +12,7 @@ |
#include "SkScalar.h" |
#include "SkTypes.h" |
-class ScaleToSides { |
+class SkScaleToSides { |
public: |
// This code assumes that a and b fit in a float, and therefore the resulting smaller value |
// of a and b will fit in a float. The side of the rectangle may be larger than a float. |
@@ -45,10 +45,10 @@ public: |
// If newMaxRadius forces the total over the limit, then it needs to be |
// reduced by one ULP to be less than limit - newMinRadius. |
// Note: nexttowardf is a c99 call and should be std::nexttoward, but this is not |
// implemented in the ARM compiler. |
if (newMaxRadius + newMinRadius > limit) { |
- newMaxRadius = nexttowardf(newMaxRadius, 0.0); |
+ newMaxRadius = nextafterf(newMaxRadius, 0.0f); |
} |
*maxRadius = newMaxRadius; |
} |
@@ -45,10 +45,10 @@ public: |
// If newMaxRadius forces the total over the limit, then it needs to be |
// reduced by one ULP to be less than limit - newMinRadius. |
- // Note: nexttowardf is a c99 call and should be std::nexttoward, but this is not |
- // implemented in the ARM compiler. |
+ // Note: nextafterf is a c99 call and should be std::nextafter, but this is not |
+ // implemented in the GCC ARM compiler. |
if (newMaxRadius + newMinRadius > limit) { |